@@ -177,7 +177,7 @@ class CameraDevice(abc.ABC):
         return False
 
     def remove_all_dark_images(self) -> None:
-        """Set the dark image for the given exposure, bin, and readout area."""
+        """Remove all dark reference images."""
         pass
 
     @property
@@ -202,6 +202,14 @@ class CameraDevice(abc.ABC):
         """
         return False
 
+    def set_gain_image(self, data: numpy.ndarray, voltage: int, bin: int) -> bool:
+        """Set the gain image for the given voltage and binning."""
+        return False
+
+    def remove_all_gain_images(self) -> None:
+        """Remove all gain reference images."""
+        pass
+
     @property
     @abc.abstractmethod
     def binning_values(self) -> typing.List[int]:
