@@ -719,6 +719,7 @@ class ScanHardwareSource(HardwareSource.HardwareSource):
             self.__stem_controller._enter_synchronized_state(self, camera=camera_hardware_source)
             self.__grab_synchronized_is_scanning = True
             self.acquisition_state_changed_event.fire(self.__grab_synchronized_is_scanning)
+            old_record_parameters = self.get_record_frame_parameters()
             scan_frame_parameters = ScanFrameParameters(scan_frame_parameters)
             scan_frame_parameters.setdefault("scan_id", str(uuid.uuid4()))
             try:
@@ -779,7 +780,16 @@ class ScanHardwareSource(HardwareSource.HardwareSource):
                                 valid_rows = partial_data_info.valid_rows
                                 src_top_row = last_valid_rows
                                 metadata = copy.deepcopy(uncropped_xdata.metadata)
-                                metadata["hardware_source"] = copy.deepcopy(scan_info.camera_metadata)
+                                # this is a hack to prevent some of the potentially misleading metadata
+                                # from getting saved into the synchronized data. while it is acceptable to
+                                # assume that the hardware_source properties will get copied to the final
+                                # metadata for now, camera implementers should be aware that this is likely
+                                # to change behavior in the future. please write tests if you make this
+                                # assumption so that they fail when this behavior is changed.
+                                metadata.setdefault("hardware_source", dict()).pop("frame_number", None)
+                                metadata.setdefault("hardware_source", dict()).pop("integration_count", None)
+                                metadata.setdefault("hardware_source", dict()).pop("valid_rows", None)
+                                metadata.setdefault("hardware_source", dict()).update(copy.deepcopy(scan_info.camera_metadata))
                                 metadata["scan"] = copy.deepcopy(scan_info.scan_metadata)
                                 metadata["instrument"] = copy.deepcopy(scan_info.instrument_metadata)
                                 metadata["scan"]["valid_rows"] = section_rect[0][0] + valid_rows
@@ -854,6 +864,7 @@ class ScanHardwareSource(HardwareSource.HardwareSource):
                         return new_scan_data_list, []
                 return None
             finally:
+                self.set_record_frame_parameters(old_record_parameters)
                 self.__stem_controller._exit_synchronized_state(self, camera=camera_hardware_source)
                 self.__grab_synchronized_is_scanning = False
                 self.acquisition_state_changed_event.fire(self.__grab_synchronized_is_scanning)
